summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog6
-rw-r--r--ChangeLog.pre-1-106
-rw-r--r--ChangeLog.pre-1-66
-rw-r--r--ChangeLog.pre-1-86
-rw-r--r--pango/pango-types.h2
-rw-r--r--pango/pango-utils.c18
6 files changed, 34 insertions, 10 deletions
diff --git a/ChangeLog b/ChangeLog
index 4abf1ade..c2afca01 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,9 @@
+Mon May 31 07:39:01 2004 Owen Taylor <otaylor@redhat.com>
+
+ * pango/pango-utils.c pango/pango-types.h (pango_matrix_concat):
+ Fix 'new' as parameter name (C++ compatibility issue).
+ (#143430, David Hawthorne)
+
Fri May 28 11:39:39 2004 Owen Taylor <otaylor@redhat.com>
* pango/pango-types.h pango/pango-utils.c: Add PangoMatrix
diff --git a/ChangeLog.pre-1-10 b/ChangeLog.pre-1-10
index 4abf1ade..c2afca01 100644
--- a/ChangeLog.pre-1-10
+++ b/ChangeLog.pre-1-10
@@ -1,3 +1,9 @@
+Mon May 31 07:39:01 2004 Owen Taylor <otaylor@redhat.com>
+
+ * pango/pango-utils.c pango/pango-types.h (pango_matrix_concat):
+ Fix 'new' as parameter name (C++ compatibility issue).
+ (#143430, David Hawthorne)
+
Fri May 28 11:39:39 2004 Owen Taylor <otaylor@redhat.com>
* pango/pango-types.h pango/pango-utils.c: Add PangoMatrix
diff --git a/ChangeLog.pre-1-6 b/ChangeLog.pre-1-6
index 4abf1ade..c2afca01 100644
--- a/ChangeLog.pre-1-6
+++ b/ChangeLog.pre-1-6
@@ -1,3 +1,9 @@
+Mon May 31 07:39:01 2004 Owen Taylor <otaylor@redhat.com>
+
+ * pango/pango-utils.c pango/pango-types.h (pango_matrix_concat):
+ Fix 'new' as parameter name (C++ compatibility issue).
+ (#143430, David Hawthorne)
+
Fri May 28 11:39:39 2004 Owen Taylor <otaylor@redhat.com>
* pango/pango-types.h pango/pango-utils.c: Add PangoMatrix
diff --git a/ChangeLog.pre-1-8 b/ChangeLog.pre-1-8
index 4abf1ade..c2afca01 100644
--- a/ChangeLog.pre-1-8
+++ b/ChangeLog.pre-1-8
@@ -1,3 +1,9 @@
+Mon May 31 07:39:01 2004 Owen Taylor <otaylor@redhat.com>
+
+ * pango/pango-utils.c pango/pango-types.h (pango_matrix_concat):
+ Fix 'new' as parameter name (C++ compatibility issue).
+ (#143430, David Hawthorne)
+
Fri May 28 11:39:39 2004 Owen Taylor <otaylor@redhat.com>
* pango/pango-types.h pango/pango-utils.c: Add PangoMatrix
diff --git a/pango/pango-types.h b/pango/pango-types.h
index 55283fbd..e953c3d0 100644
--- a/pango/pango-types.h
+++ b/pango/pango-types.h
@@ -108,7 +108,7 @@ void pango_matrix_scale (PangoMatrix *matrix,
void pango_matrix_rotate (PangoMatrix *matrix,
double degrees);
void pango_matrix_concat (PangoMatrix *matrix,
- PangoMatrix *new);
+ PangoMatrix *new_matrix);
#define PANGO_SCALE 1024
#define PANGO_PIXELS(d) (((d) >= 0) ? \
diff --git a/pango/pango-utils.c b/pango/pango-utils.c
index 6c75a3bf..96378168 100644
--- a/pango/pango-utils.c
+++ b/pango/pango-utils.c
@@ -1098,15 +1098,15 @@ pango_matrix_rotate (PangoMatrix *matrix,
/**
* pango_matrix_concat:
* @matrix: a #PangoMatrix
- * @new: a #PangoMatrix
+ * @new_matrix: a #PangoMatrix
*
* Changes the transformation represented by @matrix to be the
* transformation given by first applying transformation
* given by @new then applying the original transformation.
**/
void
pango_matrix_concat (PangoMatrix *matrix,
- PangoMatrix *new)
+ PangoMatrix *new_matrix)
{
PangoMatrix tmp;
@@ -1114,12 +1114,12 @@ pango_matrix_concat (PangoMatrix *matrix,
tmp = *matrix;
- matrix->xx = tmp.xx * new->xx + tmp.xy * new->yx;
- matrix->xy = tmp.xx * new->xy + tmp.xy * new->yy;
- matrix->yx = tmp.yx * new->xx + tmp.yy * new->yx;
- matrix->yy = tmp.yx * new->xy + tmp.yy * new->yy;
- matrix->x0 = tmp.xx * new->x0 + tmp.xy * new->y0 + tmp.x0;
- matrix->y0 = tmp.yx * new->y0 + tmp.yy * new->y0 + tmp.y0;
+ matrix->xx = tmp.xx * new_matrix->xx + tmp.xy * new_matrix->yx;
+ matrix->xy = tmp.xx * new_matrix->xy + tmp.xy * new_matrix->yy;
+ matrix->yx = tmp.yx * new_matrix->xx + tmp.yy * new_matrix->yx;
+ matrix->yy = tmp.yx * new_matrix->xy + tmp.yy * new_matrix->yy;
+ matrix->x0 = tmp.xx * new_matrix->x0 + tmp.xy * new_matrix->y0 + tmp.x0;
+ matrix->y0 = tmp.yx * new_matrix->y0 + tmp.yy * new_matrix->y0 + tmp.y0;
}
static const char canon_map[256] = {
@@ -1098,15 +1098,15 @@ pango_matrix_rotate (PangoMatrix *matrix,
* Changes the transformation represented by @matrix to be the
* transformation given by first applying transformation
- * given by @new then applying the original transformation.
+ * given by @new_matrix then applying the original transformation.
**/
void